# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLevelSetsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkBinaryMaskToNarrowBandPointSetFilterPython
else:
    import _itkBinaryMaskToNarrowBandPointSetFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkRGBPixelPython
import itk.itkImageToMeshFilterPython
import itk.itkMeshSourcePython
import itk.itkPointSetPython
import itk.itkVectorContainerPython
import itk.itkArrayPython
import itk.itkContinuousIndexPython
import itk.itkMeshBasePython
import itk.itkBoundingBoxPython
import itk.itkMapContainerPython

def itkBinaryMaskToNarrowBandPointSetFilterISS2MD2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS2MD2.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS2MD2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS2MD2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS2MD2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS2MD2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MD2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS2MD2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MD2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MD2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MD2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MD2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS2MD2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS2MD2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MD2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS2MD2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS2MD2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS2MD2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS2MD2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS2MD2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS2MD2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MD2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS2MD2)

def itkBinaryMaskToNarrowBandPointSetFilterISS2MF2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS2MF2.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS2MF2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS2MF2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS2MF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS2MF2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS2MF2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MF2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MF2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MF2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MF2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS2MF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS2MF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS2MF2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS2MF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS2MF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS2MF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS2MF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS2MF2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MF2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS2MF2)

def itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS2MSS2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS2MSS2)

def itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS2MUC2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS2MUC2)

def itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS2PSD2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS2PSD2)

def itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS2PSF2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS2PSF2)

def itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS2PSSS2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS2PSSS2)

def itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS2PSUC2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS2PSUC2)

def itkBinaryMaskToNarrowBandPointSetFilterISS3MD3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS3MD3.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS3MD3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS3MD3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS3MD3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS3MD3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MD3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS3MD3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MD3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MD3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MD3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MD3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS3MD3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS3MD3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MD3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS3MD3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS3MD3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS3MD3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS3MD3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS3MD3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS3MD3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MD3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS3MD3)

def itkBinaryMaskToNarrowBandPointSetFilterISS3MF3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS3MF3.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS3MF3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS3MF3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS3MF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS3MF3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS3MF3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MF3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MF3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MF3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MF3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS3MF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS3MF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS3MF3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS3MF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS3MF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS3MF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS3MF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS3MF3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MF3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS3MF3)

def itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS3MSS3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS3MSS3)

def itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS3MUC3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS3MUC3)

def itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS3PSD3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS3PSD3)

def itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS3PSF3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS3PSF3)

def itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS3PSSS3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS3PSSS3)

def itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3.New()

class itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterISS3PSUC3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageSS3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterISS3PSUC3)

def itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC2MD2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC2MD2)

def itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC2MF2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC2MF2)

def itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC2MSS2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC2MSS2)

def itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC2MUC2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC2MUC2)

def itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC2PSD2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC2PSD2)

def itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC2PSF2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC2PSF2)

def itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC2PSSS2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC2PSSS2)

def itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC2PSUC2):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC2 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC2PSUC2)

def itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC3MD3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC3MD3)

def itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC3MF3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC3MF3)

def itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC3MSS3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC3MSS3)

def itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC3MUC3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC3MUC3)

def itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC3PSD3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC3PSD3)

def itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC3PSF3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC3PSF3)

def itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC3PSSS3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC3PSSS3)

def itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3_New():
    return itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3.New()

class itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3(itk.itkImageToMeshFilterPython.itkImageToMeshFilterIUC3PSUC3):
    r"""Proxy of C++ itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3_Pointer"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3_Clone(self)

    def SetInput(self, inputImage):
        r"""
        SetInput(self, inputImage)

        Parameters
        ----------
        inputImage: itkImageUC3 const *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3_SetInput(self, inputImage)

    def SetBandWidth(self, _arg):
        r"""
        SetBandWidth(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3_SetBandWidth(self, _arg)

    def GetBandWidth(self):
        r"""GetBandWidth(self) -> float"""
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3_GetBandWidth(self)
    __swig_destroy__ = _itkBinaryMaskToNarrowBandPointSetFilterPython.delete_itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3

        Create a new object of the class itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3 in _itkBinaryMaskToNarrowBandPointSetFilterPython:
_itkBinaryMaskToNarrowBandPointSetFilterPython.itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3_swigregister(itkBinaryMaskToNarrowBandPointSetFilterIUC3PSUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def binary_mask_to_narrow_band_point_set_filter(*args: itkt.ImageLike,  band_width: float=..., output: itkt.PointSet=...,**kwargs)-> itkt.MeshSourceReturn:
    """Functional interface for BinaryMaskToNarrowBandPointSetFilter"""
    import itk

    kwarg_typehints = { 'band_width':band_width,'output':output }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.BinaryMaskToNarrowBandPointSetFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def binary_mask_to_narrow_band_point_set_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKLevelSets.BinaryMaskToNarrowBandPointSetFilter
    binary_mask_to_narrow_band_point_set_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    binary_mask_to_narrow_band_point_set_filter.__doc__ = filter_object.__doc__



